=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2009-12-03 19:12:18 +0000
+++ drizzled/plugin/storage_engine.cc	2009-12-05 01:45:30 +0000
@@ -720,9 +720,13 @@
     if (error == 0)
     {
       if (engine && engine->check_flag(HTON_BIT_HAS_DATA_DICTIONARY))
-        delete_table_proto_file(identifier.getPath());
+      {
+        deleteDefinitionFromPath(identifier);
+      }
       else
-        error= delete_table_proto_file(identifier.getPath());
+      {
+        error= deleteDefinitionFromPath(identifier);
+      }
     }
   }
 
@@ -1293,4 +1297,52 @@
   }
 }
 
+
+int plugin::StorageEngine::deleteDefinitionFromPath(TableIdentifier &identifier)
+{
+  string path(identifier.getPath());
+
+  path.append(DEFAULT_DEFINITION_FILE_EXT);
+
+  return my_delete(path.c_str(), MYF(0));
+}
+
+int plugin::StorageEngine::renameDefinitionFromPath(TableIdentifier &dest, TableIdentifier &src)
+{
+  string src_path(src.getPath());
+  string dest_path(dest.getPath());
+
+  src_path.append(DEFAULT_DEFINITION_FILE_EXT);
+  dest_path.append(DEFAULT_DEFINITION_FILE_EXT);
+
+  return my_rename(src_path.c_str(), dest_path.c_str(), MYF(MY_WME));
+}
+
+int plugin::StorageEngine::writeDefinitionFromPath(TableIdentifier &identifier, message::Table &table_proto)
+{
+  string file_name(identifier.getPath());
+
+  file_name.append(DEFAULT_DEFINITION_FILE_EXT);
+
+  int fd= open(file_name.c_str(), O_RDWR|O_CREAT|O_TRUNC, my_umask);
+
+  if (fd == -1)
+    return errno;
+
+  google::protobuf::io::ZeroCopyOutputStream* output=
+    new google::protobuf::io::FileOutputStream(fd);
+
+  if (table_proto.SerializeToZeroCopyStream(output) == false)
+  {
+    delete output;
+    close(fd);
+    return errno;
+  }
+
+  delete output;
+  close(fd);
+  return 0;
+}
+
+
 } /* namespace drizzled */

=== modified file 'drizzled/plugin/storage_engine.h'
--- drizzled/plugin/storage_engine.h	2009-12-03 19:12:18 +0000
+++ drizzled/plugin/storage_engine.h	2009-12-05 01:45:30 +0000
@@ -452,6 +452,11 @@
   virtual uint32_t max_supported_key_length(void) const { return MAX_KEY_LENGTH; }
   virtual uint32_t max_supported_key_part_length(void) const { return 255; }
 
+  /* TODO-> Make private */
+  static int readDefinitionFromPath(TableIdentifier &identifier, message::Table &proto);
+  static int deleteDefinitionFromPath(TableIdentifier &identifier);
+  static int renameDefinitionFromPath(TableIdentifier &dest, TableIdentifier &src);
+  static int writeDefinitionFromPath(TableIdentifier &identifier, message::Table &proto);
 };
 
 } /* namespace plugin */

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2009-11-26 05:22:18 +0000
+++ drizzled/session.cc	2009-12-05 01:45:30 +0000
@@ -1866,7 +1866,6 @@
 */
 
 void Session::close_temporary_table(Table *table)
-                         
 {
   if (table->prev)
   {
@@ -1908,6 +1907,7 @@
   rm_temporary_table(table_type, table->s->path.str);
 
   table->s->free_table_share();
+
   /* This makes me sad, but we're allocating it via malloc */
   free(table);
 }
@@ -2126,7 +2126,7 @@
 
   assert(base);
 
-  if (delete_table_proto_file(identifier.getPath()))
+  if (plugin::StorageEngine::deleteDefinitionFromPath(identifier))
     error= true;
 
   if (base->doDropTable(*this, identifier.getPath()))
@@ -2155,5 +2155,3 @@
   }
   return error;
 }
-
-

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2009-12-01 00:41:02 +0000
+++ drizzled/session.h	2009-12-05 01:45:30 +0000
@@ -1428,7 +1428,7 @@
 
   /* Create a lock in the cache */
   Table *table_cache_insert_placeholder(const char *key, uint32_t key_length);
-  bool lock_table_name_if_not_cached(const char *db, 
+  bool lock_table_name_if_not_cached(const char *db,
                                      const char *table_name, Table **table);
 
   /* Work with temporary tables */
@@ -1438,7 +1438,7 @@
   void close_temporary_tables();
   void close_temporary_table(Table *table);
   // The method below just handles the de-allocation of the table. In
-  // a better memory type world, this would not be needed. 
+  // a better memory type world, this would not be needed.
 private:
   void close_temporary(Table *table);
 public:
@@ -1448,7 +1448,7 @@
   bool rm_temporary_table(drizzled::plugin::StorageEngine *base, drizzled::TableIdentifier &identifier);
   Table *open_temporary_table(drizzled::TableIdentifier &identifier,
                               bool link_in_list= true);
-  
+
   /* Reopen operations */
   bool reopen_tables(bool get_locks, bool mark_share_as_old);
   bool reopen_name_locked_table(TableList* table_list, bool link_in);

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2009-12-03 00:18:06 +0000
+++ drizzled/sql_base.cc	2009-12-05 01:45:30 +0000
@@ -814,7 +814,9 @@
                               const char *table_name)
 {
   if (table->s->tmp_table)
+  {
     close_temporary_table(table);
+  }
   else
   {
     pthread_mutex_lock(&LOCK_open); /* Close and drop a table (AUX routine) */

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-12-03 21:51:12 +0000
+++ drizzled/sql_table.cc	2009-12-05 01:45:30 +0000
@@ -1672,7 +1672,7 @@
   session->set_proc_info("creating table");
   create_info->table_existed= 0;		// Mark that table is created
 
-  create_info->table_options=db_options;
+  create_info->table_options= db_options;
 
   if (rea_create_table(session, identifier,
 		       table_proto,

=== modified file 'drizzled/table_proto_write.cc'
--- drizzled/table_proto_write.cc	2009-12-03 02:08:38 +0000
+++ drizzled/table_proto_write.cc	2009-12-05 01:45:30 +0000
@@ -579,7 +579,7 @@
 
 err_handler:
   if (engine->check_flag(HTON_BIT_HAS_DATA_DICTIONARY) == false)
-    delete_table_proto_file(identifier.getPath());
+    plugin::StorageEngine::deleteDefinitionFromPath(identifier);
 
   return 1;
 } /* rea_create_table */

